@@ -31,6 +31,7 @@ typedef struct
   ECalClient         *client;
 
   gboolean            read_only;
+  gboolean            visible;
 
   gulong              color_changed_handler_id;
   gulong              name_changed_handler_id;
@@ -132,6 +133,16 @@ on_source_visible_changed_cb (ESourceSelectable *source,
                               GParamSpec        *pspec,
                               GcalCalendar      *self)
 {
+  GcalCalendarPrivate *priv;
+  gboolean visible;
+
+  priv = gcal_calendar_get_instance_private (self);
+  visible = e_source_selectable_get_selected (source);
+
+  if (visible == priv->visible)
+    return;
+
+  priv->visible = visible;
   g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_VISIBLE]);
 }
 
@@ -169,6 +180,7 @@ gcal_calendar_initable_init (GInitable     *initable,
     }
 
   selectable_extension = e_source_get_extension (priv->source, E_SOURCE_EXTENSION_CALENDAR);
+  priv->visible = e_source_selectable_get_selected (selectable_extension);
 
   update_color (self);
   priv->color_changed_handler_id = g_signal_connect (selectable_extension,
@@ -343,43 +355,43 @@ gcal_calendar_class_init (GcalCalendarClass *klass)
                                                  "Calendar client",
                                                  "Calendar client",
                                                  E_TYPE_CAL_CLIENT,
-                                                 G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+                                                 G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   properties[PROP_COLOR] = g_param_spec_boxed ("color",
                                                "Color",
                                                "Color of the calendar",
                                                GDK_TYPE_RGBA,
-                                               G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                                               G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   properties[PROP_ID] = g_param_spec_string ("id",
                                              "Identifier",
                                              "Unique identifier of the calendar",
                                              NULL,
-                                             G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                                             G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   properties[PROP_NAME] = g_param_spec_string ("name",
                                                "Name",
                                                "Name of the calendar",
                                                NULL,
-                                               G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                                               G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   properties[PROP_READ_ONLY] = g_param_spec_boolean ("read-only",
                                                      "Read-only",
                                                      "Whether the calendar is read-only or not",
                                                      FALSE,
-                                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+                                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   properties[PROP_SOURCE] = g_param_spec_object ("source",
                                                  "Source",
                                                  "Source",
                                                  E_TYPE_SOURCE,
-                                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+                                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   properties[PROP_VISIBLE] = g_param_spec_boolean ("visible",
                                                    "Visible",
                                                    "Whether the calendar is visible",
                                                    FALSE,
-                                                   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                                                   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, N_PROPS, properties);
 }
@@ -642,6 +654,9 @@ gcal_calendar_set_visible (GcalCalendar *self,
 
   g_return_if_fail (GCAL_IS_CALENDAR (self));
 
+  if (priv->visible == visible)
+    return;
+
   selectable_extension = e_source_get_extension (priv->source, E_SOURCE_EXTENSION_CALENDAR);
   e_source_selectable_set_selected (selectable_extension, visible);
 
