@@ -387,6 +387,7 @@ remove_recurrence_properties (GcalEvent *event)
 
   e_cal_component_set_recurid (comp, NULL);
   e_cal_component_set_rrules (comp, NULL);
+  e_cal_component_commit_sequence (comp);
 }
 
 static gchar*
@@ -654,6 +655,140 @@ clear_alarms (GcalEditDialog *self)
     }
 }
 
+static void
+apply_changes_to_event (GcalEditDialog *self)
+{
+  GcalRecurrenceFrequency freq;
+  GcalRecurrence *old_recur;
+  GDateTime *start_date, *end_date;
+  gboolean was_all_day;
+  gboolean all_day;
+  gchar *note_text;
+  gsize i;
+
+  /* Update summary */
+  gcal_event_set_summary (self->event, gtk_entry_get_text (GTK_ENTRY (self->summary_entry)));
+
+  /* Update description */
+  g_object_get (G_OBJECT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (self->notes_text))),
+                "text", &note_text,
+                NULL);
+
+  gcal_event_set_description (self->event, note_text);
+  g_free (note_text);
+
+  all_day = gtk_switch_get_active (self->all_day_switch);
+  was_all_day = gcal_event_get_all_day (self->event);
+
+  if (!was_all_day && all_day)
+    gcal_event_save_original_timezones (self->event);
+
+  /*
+   * Update start & end dates. The dates are already translated to the current
+   * timezone (unless the event used to be all day, but no longer is).
+   */
+  start_date = get_date_start (self);
+  end_date = get_date_end (self);
+
+#ifdef GCAL_ENABLE_TRACE
+    {
+      g_autofree gchar *start_dt_string = g_date_time_format (start_date, "%x %X %z");
+      g_autofree gchar *end_dt_string = g_date_time_format (end_date, "%x %X %z");
+
+      g_debug ("New start date: %s", start_dt_string);
+      g_debug ("New end date: %s", end_dt_string);
+    }
+#endif
+
+  gcal_event_set_all_day (self->event, all_day);
+
+  /*
+   * The end date for multi-day events is exclusive, so we bump it by a day.
+   * This fixes the discrepancy between the end day of the event and how it
+   * is displayed in the month view. See bug 769300.
+   */
+  if (all_day)
+    {
+      GDateTime *fake_end_date = g_date_time_add_days (end_date, 1);
+
+      g_clear_pointer (&end_date, g_date_time_unref);
+      end_date = fake_end_date;
+    }
+  else if (!all_day && was_all_day)
+    {
+      /* When an all day event is changed to be not an all day event, we
+       * need to correct for the fact that the event's timezone was until
+       * now set to UTC. That means we need to change the timezone to
+       * localtime now, or else it will be saved incorrectly.
+       */
+      GDateTime *localtime_date;
+
+      localtime_date = g_date_time_to_local (start_date);
+      g_clear_pointer (&start_date, g_date_time_unref);
+      start_date = localtime_date;
+
+      localtime_date = g_date_time_to_local (end_date);
+      g_clear_pointer (&end_date, g_date_time_unref);
+      end_date = localtime_date;
+    }
+
+  gcal_event_set_date_start (self->event, start_date);
+  gcal_event_set_date_end (self->event, end_date);
+
+  g_clear_pointer (&start_date, g_date_time_unref);
+  g_clear_pointer (&end_date, g_date_time_unref);
+
+  /* Update alarms */
+  gcal_event_remove_all_alarms (self->event);
+
+  for (i = 0; i < self->alarms->len; i++)
+    gcal_event_add_alarm (self->event, g_ptr_array_index (self->alarms, i));
+
+  clear_alarms (self);
+
+  /* Check Repeat popover and set recurrence-rules accordingly */
+  old_recur = gcal_event_get_recurrence (self->event);
+  freq = gtk_combo_box_get_active (GTK_COMBO_BOX (self->repeat_combo));
+
+  if (freq != GCAL_RECURRENCE_NO_REPEAT)
+    {
+      GcalRecurrence *recur;
+
+      recur = gcal_recurrence_new ();
+      recur->frequency = freq;
+      recur->limit_type = gtk_combo_box_get_active (GTK_COMBO_BOX (self->repeat_duration_combo));
+
+      if (recur->limit_type == GCAL_RECURRENCE_UNTIL)
+        recur->limit.until = gcal_date_selector_get_date (GCAL_DATE_SELECTOR (self->until_date_selector));
+      else if (recur->limit_type == GCAL_RECURRENCE_COUNT)
+        recur->limit.count = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (self->number_of_occurrences_spin));
+
+      /* Only apply the new recurrence if it's different from the old one */
+      if (!gcal_recurrence_is_equal (old_recur, recur))
+        {
+          /* Remove the previous recurrence... */
+          remove_recurrence_properties (self->event);
+
+          /* ... and set the new one */
+          gcal_event_set_recurrence (self->event, recur);
+
+          self->recurrence_changed = TRUE;
+        }
+
+      g_clear_pointer (&recur, gcal_recurrence_unref);
+    }
+  else
+    {
+      /* When NO_REPEAT is set, make sure to remove the old recurrent */
+      remove_recurrence_properties (self->event);
+
+      /* If the recurrence from an recurrent event was removed, mark it as changed */
+      if (old_recur && old_recur->frequency != GCAL_RECURRENCE_NO_REPEAT)
+        self->recurrence_changed = TRUE;
+    }
+}
+
+
 /*
  * Callbacks
  */
@@ -791,138 +926,16 @@ on_action_button_clicked_cb (GtkWidget *widget,
     }
   else
     {
-      GcalRecurrenceFrequency freq;
-      GcalRecurrence *old_recur;
       GcalCalendar *calendar;
-      GDateTime *start_date, *end_date;
-      gboolean was_all_day;
-      gboolean all_day;
-      gchar *note_text;
-      gsize i;
+      gint response;
 
-      /* Update summary */
-      gcal_event_set_summary (self->event, gtk_entry_get_text (GTK_ENTRY (self->summary_entry)));
+      apply_changes_to_event (self);
 
-      /* Update description */
-      g_object_get (G_OBJECT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (self->notes_text))),
-                    "text", &note_text,
-                    NULL);
-
-      gcal_event_set_description (self->event, note_text);
-      g_free (note_text);
-
-      all_day = gtk_switch_get_active (self->all_day_switch);
-      was_all_day = gcal_event_get_all_day (self->event);
-
-      if (!was_all_day && all_day)
-        gcal_event_save_original_timezones (self->event);
-
-      /*
-       * Update start & end dates. The dates are already translated to the current
-       * timezone (unless the event used to be all day, but no longer is).
-       */
-      start_date = get_date_start (self);
-      end_date = get_date_end (self);
-
-#ifdef GCAL_ENABLE_TRACE
-        {
-          g_autofree gchar *start_dt_string = g_date_time_format (start_date, "%x %X %z");
-          g_autofree gchar *end_dt_string = g_date_time_format (end_date, "%x %X %z");
-
-          g_debug ("New start date: %s", start_dt_string);
-          g_debug ("New end date: %s", end_dt_string);
-        }
-#endif
-
-      gcal_event_set_all_day (self->event, all_day);
-
-      /*
-       * The end date for multi-day events is exclusive, so we bump it by a day.
-       * This fixes the discrepancy between the end day of the event and how it
-       * is displayed in the month view. See bug 769300.
-       */
-      if (all_day)
-        {
-          GDateTime *fake_end_date = g_date_time_add_days (end_date, 1);
-
-          g_clear_pointer (&end_date, g_date_time_unref);
-          end_date = fake_end_date;
-        }
-      else if (!all_day && was_all_day)
-        {
-          /* When an all day event is changed to be not an all day event, we
-           * need to correct for the fact that the event's timezone was until
-           * now set to UTC. That means we need to change the timezone to
-           * localtime now, or else it will be saved incorrectly.
-           */
-          GDateTime *localtime_date;
-
-          localtime_date = g_date_time_to_local (start_date);
-          g_clear_pointer (&start_date, g_date_time_unref);
-          start_date = localtime_date;
-
-          localtime_date = g_date_time_to_local (end_date);
-          g_clear_pointer (&end_date, g_date_time_unref);
-          end_date = localtime_date;
-        }
-
-      gcal_event_set_date_start (self->event, start_date);
-      gcal_event_set_date_end (self->event, end_date);
-
-      g_clear_pointer (&start_date, g_date_time_unref);
-      g_clear_pointer (&end_date, g_date_time_unref);
-
-      /* Update alarms */
-      gcal_event_remove_all_alarms (self->event);
-
-      for (i = 0; i < self->alarms->len; i++)
-        gcal_event_add_alarm (self->event, g_ptr_array_index (self->alarms, i));
-
-      clear_alarms (self);
-
-      /* Check Repeat popover and set recurrence-rules accordingly */
-      old_recur = gcal_event_get_recurrence (self->event);
-      freq = gtk_combo_box_get_active (GTK_COMBO_BOX (self->repeat_combo));
-
-      if (freq != GCAL_RECURRENCE_NO_REPEAT)
-        {
-          GcalRecurrence *recur;
-
-          recur = gcal_recurrence_new ();
-          recur->frequency = freq;
-          recur->limit_type = gtk_combo_box_get_active (GTK_COMBO_BOX (self->repeat_duration_combo));
-
-          if (recur->limit_type == GCAL_RECURRENCE_UNTIL)
-            recur->limit.until = gcal_date_selector_get_date (GCAL_DATE_SELECTOR (self->until_date_selector));
-          else if (recur->limit_type == GCAL_RECURRENCE_COUNT)
-            recur->limit.count = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (self->number_of_occurrences_spin));
-
-          /* Only apply the new recurrence if it's different from the old one */
-          if (!gcal_recurrence_is_equal (old_recur, recur))
-            {
-              /* Remove the previous recurrence... */
-              remove_recurrence_properties (self->event);
-
-              /* ... and set the new one */
-              gcal_event_set_recurrence (self->event, recur);
-
-              self->recurrence_changed = TRUE;
-            }
-
-          g_clear_pointer (&recur, gcal_recurrence_unref);
-        }
-      else
-        {
-          /* When NO_REPEAT is set, make sure to remove the old recurrent */
-          remove_recurrence_properties (self->event);
-
-          /* If the recurrence from an recurrent event was removed, mark it as changed */
-          if (old_recur && old_recur->frequency != GCAL_RECURRENCE_NO_REPEAT)
-            self->recurrence_changed = TRUE;
-        }
+      response = self->event_is_new ? GCAL_RESPONSE_CREATE_EVENT : GCAL_RESPONSE_SAVE_EVENT;
 
       /* Update the source if needed */
       calendar = gcal_event_get_calendar (self->event);
+
       if (self->selected_calendar && calendar != self->selected_calendar)
         {
           if (self->event_is_new)
@@ -934,14 +947,14 @@ on_action_button_clicked_cb (GtkWidget *widget,
               gcal_manager_move_event_to_source (gcal_context_get_manager (self->context),
                                                  self->event,
                                                  gcal_calendar_get_source (self->selected_calendar));
+              response = GTK_RESPONSE_CANCEL;
             }
         }
 
       self->selected_calendar = NULL;
 
       /* Send the response */
-      gtk_dialog_response (GTK_DIALOG (self),
-                           self->event_is_new ? GCAL_RESPONSE_CREATE_EVENT : GCAL_RESPONSE_SAVE_EVENT);
+      gtk_dialog_response (GTK_DIALOG (self), response);
     }
 
   GCAL_EXIT;
@@ -1430,6 +1443,7 @@ void
 gcal_edit_dialog_set_event (GcalEditDialog *self,
                             GcalEvent      *event)
 {
+  g_autoptr (GcalEvent) cloned_event = NULL;
   GcalRecurrenceLimitType limit_type;
   GcalRecurrenceFrequency frequency;
   GcalRecurrence *recur;
@@ -1445,7 +1459,7 @@ gcal_edit_dialog_set_event (GcalEditDialog *self,
 
   g_return_if_fail (GCAL_IS_EDIT_DIALOG (self));
 
-  g_set_object (&self->event, event);
+  g_clear_object (&self->event);
 
   self->setting_event = TRUE;
 
@@ -1459,8 +1473,11 @@ gcal_edit_dialog_set_event (GcalEditDialog *self,
   if (!event)
     GCAL_GOTO (out);
 
+  cloned_event = gcal_event_new_from_event (event);
+  self->event = g_object_ref (cloned_event);
+
   /* Recurrences */
-  recur = gcal_event_get_recurrence (event);
+  recur = gcal_event_get_recurrence (cloned_event);
   frequency = recur ? recur->frequency : GCAL_RECURRENCE_NO_REPEAT;
   limit_type = recur ? recur->limit_type : GCAL_RECURRENCE_FOREVER;
 
@@ -1492,8 +1509,8 @@ gcal_edit_dialog_set_event (GcalEditDialog *self,
       break;
     }
 
-  all_day = gcal_event_get_all_day (event);
-  calendar = gcal_event_get_calendar (event);
+  all_day = gcal_event_get_all_day (cloned_event);
+  calendar = gcal_event_get_calendar (cloned_event);
 
   /* Clear event data */
   gcal_edit_dialog_clear_data (self);
@@ -1506,7 +1523,7 @@ gcal_edit_dialog_set_event (GcalEditDialog *self,
 
   /* Load new event data */
   /* summary */
-  summary = gcal_event_get_summary (event);
+  summary = gcal_event_get_summary (cloned_event);
 
   if (g_strcmp0 (summary, "") == 0)
     gtk_entry_set_text (GTK_ENTRY (self->summary_entry), _("Unnamed event"));
@@ -1514,7 +1531,7 @@ gcal_edit_dialog_set_event (GcalEditDialog *self,
     gtk_entry_set_text (GTK_ENTRY (self->summary_entry), summary);
 
   /* dialog titlebar's title & subtitle */
-  surface = get_circle_surface_from_color (gcal_event_get_color (event), 10);
+  surface = get_circle_surface_from_color (gcal_event_get_color (cloned_event), 10);
   gtk_image_set_from_surface (GTK_IMAGE (self->source_image), surface);
   g_clear_pointer (&surface, cairo_surface_destroy);
 
@@ -1522,10 +1539,10 @@ gcal_edit_dialog_set_event (GcalEditDialog *self,
   self->selected_calendar = calendar;
 
   /* retrieve start and end dates */
-  date_start = gcal_event_get_date_start (event);
+  date_start = gcal_event_get_date_start (cloned_event);
   date_start = all_day ? g_date_time_ref (date_start) : g_date_time_to_local (date_start);
 
-  date_end = gcal_event_get_date_end (event);
+  date_end = gcal_event_get_date_end (cloned_event);
   /*
    * This is subtracting what has been added in action_button_clicked ().
    * See bug 769300.
@@ -1561,11 +1578,11 @@ gcal_edit_dialog_set_event (GcalEditDialog *self,
   self->recurrence_changed = FALSE;
 
   /* location */
-  gtk_entry_set_text (GTK_ENTRY (self->location_entry), gcal_event_get_location (event));
+  gtk_entry_set_text (GTK_ENTRY (self->location_entry), gcal_event_get_location (cloned_event));
 
   /* notes */
   gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (self->notes_text)),
-                            gcal_event_get_description (event),
+                            gcal_event_get_description (cloned_event),
                             -1);
 
   set_writable (self, !gcal_calendar_is_read_only (calendar));
